@@ -35,27 +35,56 @@ pub fn parse_trade(exchange: &str, market_type: MarketType, msg: &str) -> Result
 }
 
 /// Parse level2 orderbook messages.
-pub fn parse_l2(exchange: &str, market_type: MarketType, msg: &str) -> Result<Vec<OrderBookMsg>> {
-    match exchange {
+pub fn parse_l2(
+    exchange: &str,
+    market_type: MarketType,
+    msg: &str,
+    timestamp: Option<i64>,
+) -> Result<Vec<OrderBookMsg>> {
+    let ret = match exchange {
         "binance" => exchanges::binance::parse_l2(market_type, msg),
-        "bitfinex" => exchanges::bitfinex::parse_l2(market_type, msg),
+        "bitfinex" => exchanges::bitfinex::parse_l2(
+            market_type,
+            msg,
+            timestamp.expect("Bitfinex orderbook messages doesn't have timestamp"),
+        ),
         "bitget" => exchanges::bitget::parse_l2(market_type, msg),
         "bithumb" => exchanges::bithumb::parse_l2(market_type, msg),
-        "bitmex" => exchanges::bitmex::parse_l2(market_type, msg),
+        "bitmex" => exchanges::bitmex::parse_l2(
+            market_type,
+            msg,
+            timestamp.expect("BitMEX orderbook messages don't have timestamp"),
+        ),
         "bitstamp" => exchanges::bitstamp::parse_l2(market_type, msg),
         "bitz" => exchanges::bitz::parse_l2(market_type, msg),
         "bybit" => exchanges::bybit::parse_l2(market_type, msg),
-        "coinbase_pro" => exchanges::coinbase_pro::parse_l2(market_type, msg),
+        "coinbase_pro" => exchanges::coinbase_pro::parse_l2(market_type, msg, timestamp),
         "deribit" => exchanges::deribit::parse_l2(market_type, msg),
         "ftx" => exchanges::ftx::parse_l2(market_type, msg),
-        "gate" => exchanges::gate::parse_l2(market_type, msg),
+        "gate" => exchanges::gate::parse_l2(market_type, msg, timestamp),
         "huobi" => exchanges::huobi::parse_l2(market_type, msg),
         "kraken" => exchanges::kraken::parse_l2(market_type, msg),
         "kucoin" => exchanges::kucoin::parse_l2(market_type, msg),
-        "mxc" => exchanges::mxc::parse_l2(market_type, msg),
+        "mxc" => exchanges::mxc::parse_l2(market_type, msg, timestamp),
         "okex" => exchanges::okex::parse_l2(market_type, msg),
         "zbg" => exchanges::zbg::parse_l2(market_type, msg),
         _ => panic!("Unknown exchange {}", exchange),
+    };
+    match ret {
+        Ok(mut orderbooks) => {
+            for orderbook in orderbooks.iter_mut() {
+                // sorted in ascending order by price
+                orderbook
+                    .asks
+                    .sort_by(|a, b| a.price.partial_cmp(&b.price).unwrap());
+                // sorted in descending order by price
+                orderbook
+                    .bids
+                    .sort_by(|a, b| b.price.partial_cmp(&a.price).unwrap());
+            }
+            Ok(orderbooks)
+        }
+        Err(_) => ret,
     }
 }
 
